﻿using System;
using Microwave.Classes.Interfaces;

namespace Microwave.Classes.Boundary
{
	public class PowerTube : IPowerTube
	{
		private IOutput myOutput;

		private bool IsOn = false;

		private readonly int powerTubeSize;

		public int PowerTubeSize
		{
			get { return powerTubeSize; }
		}

		public PowerTube(IOutput output, int powerTubeSize)
		{
			myOutput = output;
			this.powerTubeSize =( powerTubeSize == 500 | powerTubeSize == 700 | powerTubeSize == 800 | powerTubeSize == 1000 
								? powerTubeSize : 500);
		}

		public void TurnOn(int power)
		{
			if (power < 1 || powerTubeSize < power)
			{
				throw new ArgumentOutOfRangeException("Power", power, "Must be between 1 and " + powerTubeSize + " (incl.)");
			}

			if (IsOn)
			{
				throw new ApplicationException("PowerTube.TurnOn: is already on");
			}

			myOutput.OutputLine($"PowerTube works with {power}");
			IsOn = true;
		}

		public void TurnOff()
		{
			if (IsOn)
			{
				myOutput.OutputLine($"PowerTube turned off");
			}

			IsOn = false;
		}
	}
}