﻿using NUnit.Framework;
using System;
using System.IO;
using System.Media;
using System.Threading;
using Microwave.Classes.Boundary;
using Microsoft.VisualStudio.TestPlatform.Utilities;
using System.Linq;

namespace Microwave.Test.Unit
{
    [TestFixture]
    public class BuzzerTest
    {
        private Buzzer buzzer;

        [SetUp]
        public void Setup()
        {
            this.buzzer = new Buzzer();
        }

        [Test]
        public void Buzz_FileNotFound_ThrowsException()
        {
            // Arrange
            var invalidFileName = "nonexistent.wav";

            // Act + Assert
            var ex = Assert.Throws<FileNotFoundException>(() => this.buzzer.Buzz(1, 1, invalidFileName));
            Assert.AreEqual($"Sound file not found: {Path.Combine(Directory.GetCurrentDirectory(), "Sounds", invalidFileName)}", ex.Message);
        }

        [Test]
        public void BuzzToConsole_ConsoleOutput_PrintsBuzz()
        {
            // Arrange
            var numberOfBursts = 3;
            var burstDurationMs = 100;

            using (var stringWriter = new StringWriter())
            {
                // Redirect the console output to the StringWriter
                Console.SetOut(stringWriter);

                // Act
                this.buzzer.BuzzToConsole(numberOfBursts, burstDurationMs);

                // Assert
                var expectedOutput = string.Join(Environment.NewLine, Enumerable.Repeat("Buzz", numberOfBursts));
                Assert.AreEqual(expectedOutput, stringWriter.ToString().Trim());
            }

            // Restore the console output
            Console.SetOut(new StreamWriter(Console.OpenStandardOutput()) { AutoFlush = true });
        }
    }
}